# pyemd-rs

[![License:MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
![PyPI - Version](https://img.shields.io/pypi/v/pyemd-rs)

This library attempts to reimplement the [PyEMD](https://github.com/laszukdawid/PyEMD) library in Rust.

The original library is licensed under [Apache-2.0 Copyright 2017 Dawid Laszuk](https://github.com/laszukdawid/PyEMD/blob/master/LICENSE.md)
